package friend_circle

import (
	"applet/app/e"
	"applet/app/md/friend_circles"
	"applet/app/svc"
	svc2 "applet/app/svc/friend_circle"
	"code.fnuoos.com/EggPlanet/egg_system_rules.git/md"
	svc3 "code.fnuoos.com/EggPlanet/egg_system_rules.git/svc"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_es.git/es"
	"encoding/json"
	"fmt"
	"github.com/gin-gonic/gin"
	"time"
)

// IsCanComment
// @Summary      朋友圈-是否可以评论
// @Tags         朋友圈
// @Description  是否可以评论
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Success      200   {string}  	"许可链接"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/v1/circleFriends/isCanComment [Get]
func IsCanComment(c *gin.Context) {
	isCan, err := svc2.IsCanComment(c)
	if err != nil {
		fmt.Println("IsCanComment:::::", err.Error())
	}
	resp := friend_circles.IsCanCommentResp{IsCan: isCan}
	e.OutSuc(c, resp, nil)
}

// Comment
// @Summary      朋友圈-评论
// @Tags         朋友圈
// @Description  是否可以评论
// @Accept       json
// @Produce      json
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Success      200   {string}  	"许可链接"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/v1/circleFriends/comment [Get]
func Comment(c *gin.Context) {
	var req *friend_circles.CommentReq
	if err1 := c.ShouldBindJSON(&req); err1 != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err1.Error())
		return
	}
	isCan, err := svc2.IsCanComment(c)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if !isCan {
		e.OutErr(c, e.ERR, "当前不允许评论！")
		return
	}

	//查找朋友圈记录
	doc, err := es.FirstDoc(md.EggFriendCircleEsIndex, req.CircleIndexId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if !doc.Found { // 表示没找到数据
		e.OutErr(c, e.ERR_NOT_FAN, "朋友圈文档记录不存在")
		return
	}
	var circle md.EggFriendCircleEs
	err = json.Unmarshal(doc.Source, &circle)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	//查找评论记录
	var comment md.EggFriendCircleCommentEs
	if req.CommentIndexId != "" {
		doc1, err1 := es.FirstDoc(md.EggFriendCircleCommentEsAlias, req.CircleIndexId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if !doc1.Found { // 表示没找到数据
			e.OutErr(c, e.ERR_NOT_FAN, "评论文档记录不存在")
			return
		}
		err = json.Unmarshal(doc1.Source, &comment)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	}

	//新增es记录
	user := svc.GetUser(c)
	now := time.Now()
	imUser, err1 := svc.GetImUser(0, user.Phone)
	if err1 != nil {
		e.OutErr(c, e.ERR, err1.Error())
		return
	}
	var commentId, replyCommentId string
	if &comment != nil {
		if comment.CommentId != "" {
			replyCommentId = req.CommentIndexId
		} else {
			commentId = req.CommentIndexId
		}
	}
	createDocRet, err := es.CreateDoc(svc3.GetEggFriendCircleCommentEsIndex(user.Id), svc3.GetEggFriendCircleCommentEsIndexId(user.Id, req.CircleIndexId), md.EggFriendCircleCommentEs{
		Uid:            user.Id,
		ImUid:          imUser.UserId,
		Kind:           1,
		CircleId:       req.CircleIndexId,
		CommentId:      commentId,
		ReplyCommentId: replyCommentId,
		Content:        req.Content,
		LikesNums:      0,
		CommentNums:    0,
		State:          1,
		IsPraise:       2,
		CreatedAt:      now.Format("2006-01-02 15:04:05"),
		UpdatedAt:      now.Format("2006-01-02 15:04:05"),
	})

	fmt.Printf("CreateDoc ==> %+v \n\n", createDocRet)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	//更新朋友圈&&评论记录
	_, err = es.UpdateDoc(md.EggFriendCircleEsIndex, req.CircleIndexId, map[string]interface{}{
		"comment_nums": circle.CommentNums + 1,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if &comment != nil {
		_, err = es.UpdateDoc(md.EggFriendCircleCommentEsAlias, req.CommentIndexId, map[string]interface{}{
			"comment_nums": comment.CommentNums + 1,
		})
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
}

func CommentDelete(c *gin.Context) {
	e.OutSuc(c, "success", nil)
}

func CommentLike(c *gin.Context) {
	e.OutSuc(c, "success", nil)
}
func CommentCancelLike(c *gin.Context) {
	e.OutSuc(c, "success", nil)
}
